@@ -4,7 +4,7 @@ package Thread::Pool::Resolve;
 # Make sure we inherit from Thread::Pool
 # Make sure we do everything by the book from now on
 
-$VERSION = '0.12';
+$VERSION = '0.13';
 @ISA = qw(Thread::Pool);
 use strict;
 
@@ -1217,12 +1217,14 @@ specified now in the call to L<new>.
 
 Elizabeth Mattijsen, <liz@dijkmat.nl>.
 
-Please report bugs to <perlbugs@dijkmat.nl>.
+Maintained by LNATION, <email@lnation.org>
+
+Please report bugs to <email@lnation.org>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002-2003 Elizabeth Mattijsen <liz@dijkmat.nl>. All rights
-reserved.  This program is free software; you can redistribute it and/or
+Copyright (c) 2002-2003 Elizabeth Mattijsen <liz@dijkmat.nl>. 2025 LNATION <email@lnation.org>
+All rights reserved.  This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
